==> badger_opt-1.1.4.tar.gz: badger_opt-1.1.4/src/badger/gui/default/components/analysis_extensions.py <==
from abc import abstractmethod, ABC

import pyqtgraph as pg
from PyQt5.QtCore import pyqtSignal
from PyQt5.QtWidgets import QDialog, QVBoxLayout, QLabel, QWidget

from badger.core import Routine


class AnalysisExtension(QDialog):
    window_closed = pyqtSignal(object)

    def __init__(self, parent=None):
        super().__init__(parent=parent)

    @abstractmethod
    def update_window(self, routine: Routine):
        pass

    def closeEvent(self, event) -> None:
        self.window_closed.emit(self)
        super().closeEvent(event)


class ParetoFrontViewer(AnalysisExtension):
    def __init__(self, parent=None):
        super().__init__(parent=parent)

        self.setWindowTitle("Pareto Front Viewer")

        self.plot_widget = pg.PlotWidget()

        self.scatter_plot = self.plot_widget.plot(pen=None, symbol='o', symbolSize=10)

        layout = QVBoxLayout()
        layout.addWidget(self.plot_widget)
        self.setLayout(layout)

    def update_window(self, routine: Routine):
        if len(routine.vocs.objective_names) != 2:
            raise ValueError("cannot use pareto front viewer unless there are 2 "
                             "objectives")

        x_name = routine.vocs.objective_names[0]
        y_name = routine.vocs.objective_names[1]

        if routine.data is not None:
            x = routine.data[x_name]
            y = routine.data[y_name]

            # Update the scatter plot
            self.scatter_plot.setData(x=x, y=y)

        # set labels
        self.plot_widget.setLabel("left", y_name)
        self.plot_widget.setLabel("bottom", x_name)

==> badger_opt-1.2.1.tar.gz: badger_opt-1.2.1/src/badger/gui/default/components/analysis_extensions.py <==
from abc import abstractmethod

import pyqtgraph as pg
from PyQt5.QtCore import pyqtSignal
from PyQt5.QtWidgets import QDialog, QVBoxLayout

from badger.core import Routine


class AnalysisExtension(QDialog):
    window_closed = pyqtSignal(object)

    def __init__(self, parent=None):
        super().__init__(parent=parent)

    @abstractmethod
    def update_window(self, routine: Routine):
        pass

    def closeEvent(self, event) -> None:
        self.window_closed.emit(self)
        super().closeEvent(event)


class ParetoFrontViewer(AnalysisExtension):
    def __init__(self, parent=None):
        super().__init__(parent=parent)

        self.setWindowTitle("Pareto Front Viewer")

        self.plot_widget = pg.PlotWidget()

        self.scatter_plot = self.plot_widget.plot(pen=None, symbol="o", symbolSize=10)

        layout = QVBoxLayout()
        layout.addWidget(self.plot_widget)
        self.setLayout(layout)

    def update_window(self, routine: Routine):
        if len(routine.vocs.objective_names) != 2:
            raise ValueError(
                "cannot use pareto front viewer unless there are 2 " "objectives"
            )

        x_name = routine.vocs.objective_names[0]
        y_name = routine.vocs.objective_names[1]

        if routine.data is not None:
            x = routine.data[x_name]
            y = routine.data[y_name]

            # Update the scatter plot
            self.scatter_plot.setData(x=x, y=y)

        # set labels
        self.plot_widget.setLabel("left", y_name)
        self.plot_widget.setLabel("bottom", x_name)
